[ ![Documentation](https://img.shields.io/badge/sphinx-documentation-informational.svg)](https://oedm.vanoord.com/proxy/circleci_no_redirect/github/TUDelft-CITG/Terminal-Optimization/master/latest/07f3adf51970049c681fce29419db5d9f7aa596d/tmp/artifacts/docs/index.html)
[ ![License: MIT](https://img.shields.io/badge/License-MIT-informational.svg)](https://github.com/TUDelft-CITG/Terminal-Optimization/blob/master/LICENSE.txt)

[![CircleCI](https://circleci.com/gh/TUDelft-CITG/Terminal-Optimization.svg?style=svg&circle-token=e80be990a1415185a3aee7c7304e86bbef094eb5)](https://circleci.com/gh/TUDelft-CITG/Terminal-Optimization)

Terminal-Optimization
=====================

* Documentation can be found: [here](https://oedm.vanoord.com/proxy/circleci_no_redirect/github/TUDelft-CITG/Terminal-Optimization/master/latest/07f3adf51970049c681fce29419db5d9f7aa596d/tmp/artifacts/docs/index.html)

Features
--------

Investment Strategy Simulation - Adaptive infrastructure development parametrically driven by changing demand scenarios

Example notebooks:
* **Example 01** - Basic example of terminal development in response to changing throughput scenarios.

## Installation

Installation using *pip install terminal_optimization* is not yet available. Running following three lines in your command prompt will allow you installing the package as well:

``` bash
# Download the package
git clone https://github.com/TUDelft-CITG/Terminal-Optimization

# Go to the correct folder
cd Terminal-Optimization

# Install package
pip install -e .
```

Note
====

This project has been set up using PyScaffold 3.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.

